@@ -42,6 +42,10 @@
 #'   geom_col(data = mtcars, aes(x = hp , y = mpg, fill = cyl)) +
 #'   theme_ipea()
 #'
+
+
+
+
 theme_ipea <- function(axis_lines = 'full',
                        axis_values = TRUE,
                        legend.position = 'right',
@@ -115,21 +119,21 @@ my_pretty_breaks <- function(x, n_breaks = NULL, na.rm = TRUE,sd = 0.05,  ...) {
       return(round(breaks, t))
     }
 
-    } else {
+  } else {
 
-      # Aplica a expansão
-      range_x <- range(x)
+    # Aplica a expansão
+    range_x <- range(x)
 
-      # Calcula os breaks com o intervalo contraído
-      breaks <- seq(from = range_x[1], to = range_x[2], length.out = 5)
+    # Calcula os breaks com o intervalo contraído
+    breaks <- seq(from = range_x[1], to = range_x[2], length.out = 5)
 
-      t <- 0
-      temp <- round(breaks, t)
-      intervals <- c(diff(temp))
-      intervals <- summary(intervals)[3]
-      breaks <- seq(from = range_x[1], to = range_x[2], by = intervals)
-      breaks <- c(breaks,breaks[length(breaks)] + intervals)
-    }
+    t <- 0
+    temp <- round(breaks, t)
+    intervals <- c(diff(temp))
+    intervals <- summary(intervals)[3]
+    breaks <- seq(from = range_x[1], to = range_x[2], by = intervals)
+    breaks <- c(breaks,breaks[length(breaks)] + intervals)
+  }
 
 }
 
@@ -222,7 +226,7 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
   if(axis_values == T){
     axis.text.y  = ggplot2::element_text()
     # axis.text.x  = ggplot2::element_text(angle = x_text_angle,  hjust= hjust, margin = margin(b = vjust,unit = 'mm'))
-    axis.text.x  = ggplot2::element_text(family = "Frutiger-LT-47-LightCn", angle = x_text_angle,color = 'black',
+    axis.text.x  = ggplot2::element_text(family = "sans", angle = x_text_angle,color = 'black',
                                          hjust = hjust, vjust = vjust_angle,margin = margin(b = vjust,unit = 'mm'))
   } else if(axis_values == F){
     axis.text.x  = ggplot2::element_blank()
@@ -233,7 +237,7 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
 
 
   if(include_x_text_title == T){
-    axis.title.x  = ggplot2::element_text(family = "Frutiger-LT-47-LightCn",margin = margin(t = 4, r = 0, b = 0, l = 0, unit = 'mm'))
+    axis.title.x  = ggplot2::element_text(family = "sans",margin = margin(t = 4, r = 0, b = 0, l = 0, unit = 'mm'))
   } else if(include_x_text_title == F){
     axis.title.x  = ggplot2::element_blank()
   } else {
@@ -241,7 +245,7 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
   }
 
   if(include_y_text_title == T){
-    axis.title.y  = ggplot2::element_text(family = "Frutiger-LT-47-LightCn",margin = margin(t = 0, r = 4, b = 0, l = 0, unit = 'mm'))
+    axis.title.y  = ggplot2::element_text(family = "sans",margin = margin(t = 0, r = 4, b = 0, l = 0, unit = 'mm'))
   } else if(include_y_text_title == F){
     axis.title.y  = ggplot2::element_blank()
   } else {
@@ -270,8 +274,8 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
 
 
   theme <- ggplot2::theme(
-    text = ggplot2::element_text(family = "Frutiger-LT-55-Roman"),
-    #text = ggplot2::element_text(family = "Frutiger-LT-55-Roman",size = unit(6, unit = 'mm')),
+    text = ggplot2::element_text(family = "sans"),
+    #text = ggplot2::element_text(family = "sans",size = unit(6, unit = 'mm')),
     # Sets the background color of the panel to white
     panel.background = ggplot2::element_rect(fill = "white", colour = NA),
     # Sets the panel border based on the previous assignment
@@ -309,25 +313,25 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
     # Sets the appearance of the plot title
     plot.title = ggplot2::element_text(
       # FullName (Frutiger LT 47 Light Condensed). FamillyName (Frutiger LT 47 LightCn)
-      family = "Frutiger-LT-47-LightCn",
+      family = "sans",
       hjust = 0,  lineheight = .5,
       margin = margin(0,0,1,0, unit = 'mm')
     ),
     # Sets the appearance of the plot subtitle
     plot.subtitle = ggplot2::element_text(
       # FullName (Frutiger LT Std 57 Condensed). FamillyName (Frutiger LT Std)
-      family = "Frutiger-LT-55-Roman",
+      family = "sans",
       face = "bold", hjust = 0,  lineheight = 1,
       margin = margin(0,0,2,0, unit = 'mm'),
     ),
-    # axis.text = ggplot2::element_text(family = "Frutiger-LT-47-LightCn", size = unit(6, "pt")),
+    # axis.text = ggplot2::element_text(family = "sans", size = unit(6, "pt")),
     plot.margin=unit(c(.2,.5,.2,.2),"cm"),
     # Spacing between faceted plots
     panel.spacing = unit(4, "mm"),
     # Sets the appearance of the legend text
     #legend.text = ggplot2::element_text(size = 7),
     # Set caption position
-    plot.caption = ggplot2::element_text(family = "Frutiger-LT-Std", hjust = 0, vjust = 0,  lineheight = 1.25),
+    plot.caption = ggplot2::element_text(family = "sans", hjust = 0, vjust = 0,  lineheight = 1.25),
     # Set the horizontal alignment of the legend to center
     legend.justification = "center",
     # Set legend spacing y
@@ -415,10 +419,10 @@ ggplot_add.scale_auto_ipea <- function(object, plot, object_name, ...) {
   test <- NULL
   for (i in seq_along(plot$layers)) {
     temp <- ifelse(grepl('bar',plot$layers[[i]]$constructor),'Bar chart',
-            ifelse(grepl('ribbon',plot$layers[[i]]$constructor),'Ribbon',
-            ifelse(grepl('area',plot$layers[[i]]$constructor),'Area',
-            ifelse(grepl('histogram',plot$layers[[i]]$constructor),'Histogram',
-            ifelse(grepl('density',plot$layers[[i]]$constructor),'Density',NA)))))
+                   ifelse(grepl('ribbon',plot$layers[[i]]$constructor),'Ribbon',
+                          ifelse(grepl('area',plot$layers[[i]]$constructor),'Area',
+                                 ifelse(grepl('histogram',plot$layers[[i]]$constructor),'Histogram',
+                                        ifelse(grepl('density',plot$layers[[i]]$constructor),'Density',NA)))))
     temp <- temp[!is.na(temp)]
     test <- rbind(test,temp)
 
